# from Products.PythonScripts.standard import html_quote
#RESPONSE =  request.RESPONSE

request = container.REQUEST
#PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')

PATH = context.getInstancePath()

Otype = request['dol']

OccOT=[]
OccObj=[]

for x in context.Data.ObjectType.objectIds(): 
    PATHOBJTYPE = PATH + '/Data/ObjectType/' + x
    ObjTypeRef = context.restrictedTraverse(PATHOBJTYPE)
    for y in ObjTypeRef.propertyIds():
        if Otype==y:
             OccOT.append(x)

for p in context.Data.Objects.objectIds(): 
     PATHOBJ = PATH + '/Data/Objects/' + p
     ObjRef = context.restrictedTraverse(PATHOBJ)
     for q in ObjRef.propertyIds():
         if Otype==q:
             OccObj.append(p)
if OccOT==[]:
   if OccObj==[]:
      return 1

return 0
